#ifndef MIDIMon_hxx
#define MIDIMon_hxx

#include <CLAM/OutControl.hxx>
#include <CLAM/Processing.hxx>

#include "RtMidi.hxx"

 namespace CLAM {

	class MIDIMon : public CLAM::Processing
	{ 
		OutControl MIDIMessage;
		OutControl MIDIData1;
		OutControl MIDIData2;

		RtMidiIn *midiin;
		std::vector<unsigned char> message;
		int nBytes;

	public:
		//typedef MidiMonConfig Config;

		const char* GetClassName() const { return "MIDIMon"; }
		MIDIMon(const Config& config = Config()) 
			: MIDIMessage("MIDI Message", this),
			  MIDIData1("MIDI Data 1", this),
			  MIDIData2("MIDI Data 2", this)
		{
			// Create RtMidiIn Object
			try {
				midiin = new RtMidiIn();
			}
			catch ( RtError &error ) {
				error.printMessage();
				exit( EXIT_FAILURE );
			}

			// Don't ignore sysex, timing, or active sensing messages.
			midiin->ignoreTypes( false, false, false );	  

			// Open Virtual Port
			try {
				midiin->openVirtualPort("CLAM - MIDIMon In");
			}
			catch ( RtError &error ) {
				error.printMessage();
			}
			Configure( config );
		}
		
		bool Do()
		{
			midiin->getMessage( &message );
		    nBytes = message.size();
			
			/*for ( int i=0; i<nBytes; i++ )
		      std::cout << "Byte " << i << " = " << (int)message[i] << "nBytes: " << nBytes << std::endl;
		    */
			if(nBytes > 0){
				MIDIMessage.SendControl((float)message[0]);
				MIDIData1.SendControl((float)message[1]);
				MIDIData2.SendControl((float)message[2]);
			}
			return true;
		}
		
	};
	
} // End namespace
#endif // MIDIMon_hxx
